@@ -4,12 +4,12 @@
  */
 package org.mockito.internal.configuration;
 
+import java.lang.reflect.Field;
+
 import org.mockito.Mock;
 import org.mockito.MockSettings;
 import org.mockito.Mockito;
 
-import java.lang.reflect.Field;
-
 /**
  * Instantiates a mock on a field annotated by {@link Mock}
  */
@@ -35,6 +35,9 @@ public class MockAnnotationProcessor implements FieldAnnotationProcessor<Mock> {
         if(annotation.stubOnly()){
             mockSettings.stubOnly();
         }
+        if(annotation.lenient()){
+            mockSettings.lenient();
+        }
 
         // see @Mock answer default value
         mockSettings.defaultAnswer(annotation.answer());
