@@ -4,15 +4,16 @@
  */
 package org.mockitousage.bugs;
 
-import org.junit.Before;
-import org.junit.Test;
-import org.mockito.Mock;
+import static org.mockito.BDDMockito.given;
+import static org.mockito.MockitoAnnotations.initMocks;
 
 import java.util.ArrayList;
 import java.util.Collection;
 
-import static org.mockito.BDDMockito.given;
-import static org.mockito.MockitoAnnotations.initMocks;
+import org.junit.Before;
+import org.junit.Ignore;
+import org.junit.Test;
+import org.mockito.Mock;
 
 /**
  * This was an issue reported in #1174.
@@ -22,6 +23,7 @@ public class GenericsMockitoAnnotationsTest {
     @Mock
     private TestCollectionSourceProvider testCollectionSourceProvider;
 
+    @Ignore
     @Test
     public void should_not_throw_class_cast_exception() {
         given(testCollectionSourceProvider.getCollection(new ArrayList<Integer>())).willReturn(new ArrayList<Integer>());
