@@ -1,3 +1,7 @@
+/*
+ * Copyright (c) 2017 Mockito contributors
+ * This program is made available under the terms of the MIT License.
+ */
 package org.mockitousage.plugins.stacktrace;
 
 import org.mockito.exceptions.stacktrace.StackTraceCleaner;
@@ -12,12 +16,13 @@ public class MyStackTraceCleanerProvider implements StackTraceCleanerProvider {
 
     public StackTraceCleaner getStackTraceCleaner(final StackTraceCleaner defaultCleaner) {
         return new StackTraceCleaner() {
-            public boolean isOut(StackTraceElement candidate) {
-                if (ENABLED && candidate.getMethodName().contains("excludeMe")) {
-                    return true;
+			@Override
+			public boolean isIn(StackTraceElement candidate) {
+				if (ENABLED && candidate.getMethodName().contains("excludeMe")) {
+                    return false;
                 }
-                return defaultCleaner.isOut(candidate);
-            }
+                return defaultCleaner.isIn(candidate);
+			}
         };
     }
-}
\ No newline at end of file
+}
